package com.inspect.metadata.version.mapper;

import com.inspect.metadata.version.domain.VersionManagement;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface VersionManagementMapper {
    VersionManagement selectVersionManagementByVersionId(Long versionId);

    List<VersionManagement> selectVersionManagementList(VersionManagement management);

    int insertVersionManagement(VersionManagement versionManagement);

    int updateVersionManagement(VersionManagement versionManagement);

    int deleteVersionManagementByVersionId(Long versionId);

    int deleteVersionManagementByVersionIds(Long[] versionIds);

    List<VersionManagement> getNewVersionInfo();
}
